<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * Author: Abdo Abouzaid <abouzaid@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 */
namespace Pinpoint\ProductEnquire\Block;

use Magento\Catalog\Block\Product\View as ProductBlock;
use Magento\Catalog\Model\Product;
use Magento\Catalog\Pricing\Price\FinalPrice;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Magento\Store\Model\ScopeInterface;
use Magento\Catalog\Helper\Image;
use Magento\Framework\Pricing\Helper\Data as PricingHelper;

class Contact extends Template
{
    private const STORE_PHONE_NUMBER_CONFIG_PATH = 'general/store_information/phone';

    /**
     * @var ProductBlock
     */
    private ProductBlock $productBlock;

    /**
     * @var Image
     */
    private Image $imageHelper;

    /**
     * @var PricingHelper
     */
    private PricingHelper $pricingHelper;

    /**
     * Constructor
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param ScopeConfigInterface $scopeConfig
     * @param ProductBlock $productBlock
     * @param Image $imageHelper
     * @param \Magento\Framework\Pricing\Helper\Data $pricingHelper
     */
    public function __construct(
        Context $context,
        ScopeConfigInterface $scopeConfig,
        ProductBlock $productBlock,
        Image $imageHelper,
        PricingHelper $pricingHelper
    ) {
        parent::__construct($context);
        $this->scopeConfig = $scopeConfig;
        $this->productBlock = $productBlock;
        $this->imageHelper = $imageHelper;
        $this->pricingHelper = $pricingHelper;
    }

    /**
     * Get Product Object
     * @return  \Magento\Catalog\Model\Product
     */
    public function getProduct(): Product
    {
        return $this->productBlock->getProduct();
    }

    /**
     * get product final price
     *
     * @return float
     */
    public function getProductFinalPrice(): float
    {
        $price =  $this->getProduct()->getPriceInfo()
            ->getPrice(FinalPrice::PRICE_CODE)
            ->getAmount()
            ->getValue();

        return (float)$this->pricingHelper->currency($price, true, false);
    }

    /**
     * Get Store phone
     *
     * @return string|null
     */
    public function getStorePhone(): ?string
    {
        return $this->scopeConfig->getValue(self::STORE_PHONE_NUMBER_CONFIG_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * get Product Image
     *
     * @return string
     */
    public function getProductImage(): string
    {
        $product = $this->getProduct();
        return $this->imageHelper->init($product, 'product_base_image')->getUrl();
    }
}
