<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 * Author: Abdo Abouzaid <abouzaid@pinpointdesigns.co.uk>
 * Code Release Version: 1.0
 * Website: http://www.pinpointdesigns.co.uk
 */

namespace Pinpoint\ProductEnquire\Controller\Adminhtml\Index;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Action\HttpGetActionInterface as HttpGetActionInterface;
use Magento\Framework\View\Result\PageFactory;
use Pinpoint\ProductEnquire\Model\ProductEnquireFactory;

class View extends Action implements HttpGetActionInterface
{
    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected PageFactory $resultPageFactory;

    /**
     * @var ProductEnquireFactory
     */
    protected ProductEnquireFactory $enquiryFactory;

    /**
     * Constructor
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Pinpoint\ProductEnquire\Model\ProductEnquireFactory $enquiryFactory
     */
    public function __construct(
        Context               $context,
        PageFactory           $resultPageFactory,
        ProductEnquireFactory $enquiryFactory
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->enquiryFactory = $enquiryFactory;
    }

    /**
     * Execute view controller
     * @return \Magento\Framework\View\Result\Page|\Magento\Framework\Controller\ResultInterface|\Magento\Framework\App\ResponseInterface
     * {@inheritdoc}
     */
    public function execute()
    {
        $resultPage = $this->resultPageFactory->create();
        $resultPage->getConfig()->getTitle()->prepend((__('Product Enquiry')));
        $resultPage = $this->resultPageFactory->create();

        try {
            $enquiryId = $this->getRequest()->getParam('id');
            $enquiry = $this->enquiryFactory->create()->load($enquiryId);

            if (!$enquiry->getId()) {
                $this->messageManager->addError('Selected Enquiry Not found');
            }

            $block = $resultPage->getLayout()->getBlock('enquiry_view');
            $block->setData('enquiry', $enquiry);
            return $resultPage;
        } catch (\Exception $e) {
            $this->messageManager->addError(__('Something went wrong, %1', $e->getMessage()));
        }

        return $this->_redirect('enquiry/index');
    }
}
